"""

author: @endormi

Very simple char functions

"""


def is_ascii_char(input):
    if isinstance(input, str):
        # Check if the input character has an ASCII code between 0 and 127
        if 0 <= ord(input) < 128:
            return True
    return False


def is_same_char(char):
    return all(c == char[0] for c in char[1:])


def is_string(char):
    return type(char) == str


def is_unicode_char(input):
    if isinstance(input, str):
        # Encode the string as UTF-8 and check
        # if it contains non-ASCII characters
        if len(input.encode('utf-8')) > len(input):
            return True
    return False


def repeat_char(char, num_of_times):
    return (char * (num_of_times//len(char) + 1))[:num_of_times]



import setuptools

with open("README.md", "r") as pkg:
    long_description = pkg.read()

setuptools.setup(
    name="charred",
    version="0.1.11",
    author="Endormi",
    author_email="contactendormi@gmail.com",
    description="Very simple char functions",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/endormi",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3',
)



import unittest
from charred import is_ascii_char, is_same_char, is_string, is_unicode_char, repeat_char


class TestChar(unittest.TestCase):
    def test_is_ascii_char(self):
        self.assertEqual(is_ascii_char('$'), True)
        self.assertEqual(is_ascii_char('£'), False)

    def test_is_same_char(self):
        self.assertEqual(is_same_char('FF'), True)
        self.assertEqual(is_same_char('FD'), False)

    def test_is_string(self):
        self.assertEqual(is_string('F'), True)
        self.assertEqual(is_string(1), False)

    def test_is_unicode_char(self):
        self.assertEqual(is_unicode_char('£'), True)
        self.assertEqual(is_unicode_char('F'), False)

    def test_char_repeat(self):
        self.assertEqual(repeat_char('F', 6), 'FFFFFF')


if __name__ == '__main__':
    unittest.main()
